@@ -84,4 +84,15 @@ class TwitterRankAnalysisDoc(object):
         self.popularity: float = popularity
         self.influence: float = influence
         self.activity: float = activity
-        self.rank: float = rank
\ No newline at end of file
+        self.rank: float = rank
+
+
+class TwitterCredibilityDoc(object):
+    def __init__(self, cap: dict = None, display_scores: dict = None, analysed: bool = False):
+        self.analysed: bool = analysed
+        self.english_score: float = cap.get("english", 0.0) if cap is not None else 0.0
+        self.universal_score: float = cap.get("universal", 0.0) if cap is not None else 0.0
+        self.english_display_scores: dict = display_scores.get("english", {}) if\
+            display_scores is not None else {}
+        self.universal_display_scores: dict = display_scores.get("universal", {}) if\
+            display_scores is not None else {}
